VirtualGridView class

A high-performance virtual scrolling grid view.

This widget provides efficient memory usage by only rendering grid items that are currently visible in the viewport.

Inheritance

Constructors

VirtualGridView({Key? key, required int itemCount, required IndexedWidgetBuilder itemBuilder, required SliverGridDelegate gridDelegate, ScrollController? controller, ScrollPhysics? physics, EdgeInsetsGeometry? padding, double cacheExtent = 250.0})
Creates a virtual grid view.
const

Properties

cacheExtent double
The amount of space to cache beyond the visible viewport.
final
controller ScrollController?
Controller for managing scroll behavior.
final
gridDelegate SliverGridDelegate
Controls the layout of the children within the grid.
final
hashCode int
The hash code for this object.
no setterinherited
itemBuilder IndexedWidgetBuilder
Builder function for creating grid items.
final
itemCount int
The total number of items in the grid.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
The amount of space by which to inset the children.
final
physics ScrollPhysics?
How the scroll view should respond to user input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited